/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
import gameframe.graphics.*;
import gameframe.sound.*;
import gameframe.input.*;
import gameframe.util.*;
import gameframe.*;

import java.io.FileNotFoundException;

/**
 * Example code how to load and show keycoloured bitmaps with
 * GameFrame for Java. Also shows how the double buffered approach
 * to animation works.
 *
 *@author Pasi Kernen 30. Jan 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class GraphicsExample2 extends GraphicsExample1
{
    /** The pink ghost bitmap. */
    protected Bitmap m_pinkGhost;
    /** The wireframe ghost bitmap. */
    protected Bitmap m_wireGhost;
    
    /**
     * Starts up the example application (creates an
     * instance and calls the run() method in the instance).
     */
    public static void main( String[] args )
    {
        GraphicsExample2 instance = new GraphicsExample2( args );
        instance.run();
    }
    
    /**
     * Constructs the example application and stores the command line
     * arguments given.
     *@param args The command line arguments.
     */
    public GraphicsExample2( String[] args )
    {
        super( args );
    }
    
    /**
     * Sets the GameFrame settings to the given settings object.
     * Overridden to change the title.
     *@param gameFrameSettings The settings to be configured.
     */
    protected void setGameFrameSettings( GameFrameSettings gameFrameSettings )
    {
        super.setGameFrameSettings( gameFrameSettings );
        gameFrameSettings.setTitle( "Graphics Example 2" );
    }

    /**
     * Initializes the example.
     */
    protected void init()
    {
        // Load and setup the background image. Also sets up the data directory.
        super.init();
        
        try
        {
            // Now we load two pictures of ghosts that both use the keycolouring
            // You can load the bitmaps m_pinkGhost.bmp and m_wireGhost.bmp into your bitmap
            // editor and see how they are drawn. Note that you DON'T give the
            // bmp suffix to the library. This is to allow easy adding of support
            // for more picture formats in the future.
            m_pinkGhost = m_grfxEngine.loadAlphaBitmap( "pinkGhost" );
            m_wireGhost = m_grfxEngine.loadAlphaBitmap( "wireGhost" );
        }
        catch( FileNotFoundException noSuchFile )
        {
            System.out.println("FileNotFound:\n"+noSuchFile.getMessage() );
            GameFrame.exit( 0 );
        }
        catch( GameFrameException gameFrameError )
        {
            System.out.println("GameFrameException:\n"+gameFrameError.getMessage() );
            GameFrame.exit( 0 );
        }
    }

    /**
     * The method where the game should be executed. Animates the two ghosts moving
     * around against the tile background.
     */
    protected void executeCodeThatUsesGameFrame()
    {
        // We get the width of the ghost
        int ghostWidth = m_pinkGhost.getWidth();
        int oppositeX;

        for ( int x = -ghostWidth; x < WIDTH + ghostWidth; x++ )
        {
            // Calculate the x-coordinate for wireframe ghosts
            oppositeX  = WIDTH + ghostWidth - x;
            
            // First we draw the background image to the backbuffer
            m_backgroundBitmap.blitTo( 0, 0 );
            
            // Then we draw the pink ghosts to the backbuffer
            m_pinkGhost.blitTo( x,  16 );
            m_pinkGhost.blitTo( x, 144 );
            m_pinkGhost.blitTo( x, 272 );
            m_pinkGhost.blitTo( x, 400 );
            
            // Then we draw the wireframe ghost to the backbuffer
            m_wireGhost.blitTo( oppositeX,  80 );
            m_wireGhost.blitTo( oppositeX, 208 );
            m_wireGhost.blitTo( oppositeX, 336 );
            
            // Then we just flip the backbuffer with the frontbuffer
            // making the just drawn graphics visible on the screen
            m_grfxEngine.flip();
        }
    }
}
