/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
import gameframe.graphics.*;
import gameframe.sound.*;
import gameframe.input.*;
import gameframe.util.*;
import gameframe.*;

import java.awt.event.KeyEvent;

/**
 * How to initialize and read the keyboard.
 * Example code how to initialize input devices and how to use
 * the different methods for reading the keyboard.
 * The pink ghost moves with the arrow keys,
 * the wireframe ghost follows the mouse and feels
 * pink when mouse button is pressed.
 *
 *@author Pasi Kernen 19. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class InputExample2 extends InputExample1
{
    /** The pointer device. */
    protected PointerDevice m_pointer;
    
    /**
     * Starts up the example application (creates an
     * instance and calls the run() method in the instance).
     */
    public static void main( String[] args )
    {
        InputExample2 instance = new InputExample2( args );
        instance.run();
    }
    
    /**
     * Constructs the example application and stores the command line
     * arguments given.
     *@param args The command line arguments.
     */
    public InputExample2( String[] args )
    {
        super( args );
    }
    
    /**
     * Sets the GameFrame settings to the given settings object.
     * Overridden to change the title.
     *@param gameFrameSettings The settings to be configured.
     */
    protected void setGameFrameSettings( GameFrameSettings gameFrameSettings )
    {
        super.setGameFrameSettings( gameFrameSettings );
        gameFrameSettings.setTitle( "Input Example 2" );
    }

    /**
     * Initializes the example.
     */
    protected void init()
    {
        // Load and setup the background image. Also sets up the data directory.
        super.init();
        
        try
        {
            // then we can get the default pointer (just in case
            // there are several pointer like devices attached).
            m_pointer = m_inputEngine.getDefaultPointerDevice();
        }
        catch( GameFrameException gameFrameError )
        {
            System.out.println("GameFrameException:\n"+gameFrameError.getMessage() );
            GameFrame.exit( 0 );
        }
    }

    /**
     * The method where the game should be executed. Animates the two ghosts moving
     * around against the tile background.
     */
    protected void executeCodeThatUsesGameFrame()
    {
        // Define the start coordinates for the ghosts
        int pinkGhostX = WIDTH/2;
        int pinkGhostY = HEIGHT/2;
        int wireGhostX = WIDTH/2;
        int wireGhostY = HEIGHT/2;
        
        m_grfxEngine.setBackgroundColor( java.awt.Color.lightGray );

        // We check if user has pressed the ESC key by using
        // the wasPressed() method as it doesn't require the
        // key to be pressed at the moment we read it
        while( !m_keyboard.wasKeyDown( KeyEvent.VK_ESCAPE ) )
        {
            m_grfxEngine.clearBackbuffer();
            
            if( m_keyboard.isKeyDown( KeyEvent.VK_UP ) )
            {
                pinkGhostY--;
                if ( pinkGhostY < 0 )
                {
                    pinkGhostY = 0;
                }
            }
            if( m_keyboard.isKeyDown( KeyEvent.VK_DOWN ) )
            {
                pinkGhostY++;
                if ( pinkGhostY > HEIGHT )
                {
                    pinkGhostY = HEIGHT;
                }
            }
            if( m_keyboard.isKeyDown( KeyEvent.VK_LEFT ) )
            {
                pinkGhostX--;
                if ( pinkGhostX < 0 )
                {
                    pinkGhostX = 0;
                }
            }
            if( m_keyboard.isKeyDown( KeyEvent.VK_RIGHT ) )
            {
                pinkGhostX++;
                if ( pinkGhostX > WIDTH )
                {
                    pinkGhostX = WIDTH;
                }
            }

            // Make the wireframe ghost follow the mouse
            wireGhostX = m_pointer.getX();
            wireGhostY = m_pointer.getY();
            
            // Check if the mouse has left the screen
            // in that case center the wireframe ghost
            if ( wireGhostX == -1 )
            {
                wireGhostX = WIDTH/2;
                wireGhostY = HEIGHT/2;
            }
            
            m_pinkGhost.blitTo( pinkGhostX, pinkGhostY );
            
            if ( m_pointer.isButtonDown( 0 ) )
            {
                m_pinkGhost.blitTo( wireGhostX, wireGhostY );
            }
            else
            {
                m_wireGhost.blitTo( wireGhostX, wireGhostY );
            }
            
            // Then we just flip the backbuffer with the frontbuffer
            // making the just drawn graphics visible on the screen
            m_grfxEngine.flip();
        }
    }
}
