/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
import gameframe.graphics.*;
import gameframe.sound.*;
import gameframe.input.*;
import gameframe.util.*;
import gameframe.*;

import java.io.FileNotFoundException;

/**
 * Loading and looping a music.
 * Example code how to load and playing looped music.
 *
 *@author Pasi Kernen 19. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class SoundExample2 extends SoundExample1
{
    /** The music. */
    protected Music m_backgroundMusic;
    
    /**
     * Starts up the example application (creates an
     * instance and calls the run() method in the instance).
     */
    public static void main( String[] args )
    {
        SoundExample2 instance = new SoundExample2( args );
        instance.run();
    }
    
    /**
     * Constructs the example application and stores the command line
     * arguments given.
     *@param args The command line arguments.
     */
    public SoundExample2( String[] args )
    {
        super( args );
    }
    
    /**
     * Sets the GameFrame settings to the given settings object.
     * Overridden to change the title.
     *@param gameFrameSettings The settings to be configured.
     */
    protected void setGameFrameSettings( GameFrameSettings gameFrameSettings )
    {
        super.setGameFrameSettings( gameFrameSettings );
        gameFrameSettings.setTitle( "Sound Example 2" );
    }

    /**
     * Initializes the example by loading two tile images and then constructing a background
     * image using those two tile images.
     */
    protected void init()
    {
        // Get the needed engines and load the explosion sample
        super.init();
        
        try
        {
            // We just load the music we want to play
            m_backgroundMusic = m_soundEngine.loadMusic( "music" );
        }
        catch( FileNotFoundException noSuchFile )
        {
            System.out.println("FileNotFound:\n"+noSuchFile.getMessage() );
            GameFrame.exit( 0 );
        }
        catch( GameFrameException gameFrameError )
        {
            System.out.println("GameFrameException:\n"+gameFrameError.getMessage() );
            GameFrame.exit( 0 );
        }
    }
    
    /**
     * The method where the game should be executed.
     */
    protected void executeCodeThatUsesGameFrame()
    {
        String strText = "Playing Music";
        
        // Check if the used GF4J implementation can play music
        if ( m_backgroundMusic instanceof gameframe.engines.NullMusic )
        {
            strText = "Unable to play music under this Java VM";
        }
        
        int middleX = ( WIDTH - m_grfxEngine.getTextWidth( strText ) ) / 2;
        int middleY = ( HEIGHT - m_grfxEngine.getFontHeight() ) / 2;

        String strText2 = "Press SPACE to explode or ESC to exit";
        int middleX2 = ( WIDTH - m_grfxEngine.getTextWidth( strText2 ) ) / 2;
        int middleY2 = middleY + m_grfxEngine.getFontHeight();
        // We draw the text to backbuffer
        try
        {
            m_grfxEngine.drawTextAt( strText, middleX, middleY );
            m_grfxEngine.drawTextAt( strText2, middleX2, middleY2 );
        }
        catch( GameFrameException error )
        {
            System.out.println( "Exception:\n"+error.getMessage() );
            GameFrame.exit(0);
        }
        
        // We flip the background buffer with the current front buffer thus making the
        // background buffer we just draw into the visible front buffer
        m_grfxEngine.flip();

        // We play the music looping forever
        m_backgroundMusic.playLooped();

        // Continue until user presses ESC key
        while( !m_keyboard.wasKeyDown( java.awt.event.KeyEvent.VK_ESCAPE ) )
        {
            // Check if user has pressed SPACE
            if ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_SPACE ) )
            {
                // Wait until user releases SPACE
                while ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_SPACE ) ) 
                {
                    try
                    {
                        // Prevent this thight loop from hogging all CPU time
                        Thread.currentThread().sleep( 50 );
                    }
                    catch( InterruptedException ie1 )
                    {
                    }
                }
                
                // And play the sound
                m_explosion.playOnce();
            }
            
            try
            {
                // Prevent this thight loop from hogging all CPU time
                Thread.currentThread().sleep( 50 );
            }
            catch( InterruptedException ie2 )
            {
            }
        }
        
        m_backgroundMusic.stop();
    }
}
