/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
import gameframe.graphics.*;
import gameframe.sound.*;
import gameframe.input.*;
import gameframe.util.*;
import gameframe.*;

import java.io.FileNotFoundException;

/**
 * Using pan and volume.
 * Example code how to set the pan and volume of a sample sound.
 * This example doesn't work under Java 2 (JDK 1.2) platforms as
 * Java 2 offers no methods to set the pan and volume of a sound.
 *
 *@author Pasi Kernen 19. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class SoundExample3 extends SoundExample2
{
    /**
     * Starts up the example application (creates an
     * instance and calls the run() method in the instance).
     */
    public static void main( String[] args )
    {
        SoundExample3 instance = new SoundExample3( args );
        instance.run();
    }
    
    /**
     * Constructs the example application and stores the command line
     * arguments given.
     *@param args The command line arguments.
     */
    public SoundExample3( String[] args )
    {
        super( args );
    }
    
    /**
     * Sets the GameFrame settings to the given settings object.
     * Overridden to change the title.
     *@param gameFrameSettings The settings to be configured.
     */
    protected void setGameFrameSettings( GameFrameSettings gameFrameSettings )
    {
        super.setGameFrameSettings( gameFrameSettings );
        gameFrameSettings.setTitle( "Sound Example 3" );
    }

    /**
     * The method where the game should be executed.
     */
    protected void executeCodeThatUsesGameFrame()
    {
        float pan = 0.0F;
        float vol = 1.0F;
        
        String strText = "Playing Explosion";
        int middleX = ( WIDTH - m_grfxEngine.getTextWidth( strText ) ) / 2;
        int middleY = ( HEIGHT - m_grfxEngine.getFontHeight() ) / 2;

        String strText2 = "Left and right to move the pan";
        int middleX2 = ( WIDTH - m_grfxEngine.getTextWidth( strText2 ) ) / 2;
        int middleY2 = middleY + m_grfxEngine.getFontHeight();

        String strText3 = "Up and down to adjust the volume";
        int middleX3 = ( WIDTH - m_grfxEngine.getTextWidth( strText3 ) ) / 2;
        int middleY3 = middleY2 + m_grfxEngine.getFontHeight();

        String strText4 = "Press ESC to exit";
        int middleX4 = ( WIDTH - m_grfxEngine.getTextWidth( strText4 ) ) / 2;
        int middleY4 = middleY3 + m_grfxEngine.getFontHeight();

        int panX = ( WIDTH - m_grfxEngine.getTextWidth( "Pan:  " ) ) / 2;
        int panY = middleY4 + m_grfxEngine.getFontHeight();

        int volX = ( WIDTH - m_grfxEngine.getTextWidth( "Vol:  " ) ) / 2;
        int volY = panY + m_grfxEngine.getFontHeight();
        
        // We play the explosion sound looping
        m_explosion.playLooped();
        
        // Continue until user presses ESC key
        while( !m_keyboard.wasKeyDown( java.awt.event.KeyEvent.VK_ESCAPE ) )
        {
            if ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_LEFT ) )
            {
                pan = pan - 0.1F;
                if ( pan < -1.0F )
                {
                    pan = -1.0F;
                }
            }
            if ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_RIGHT ) )
            {
                pan = pan + 0.1F;
                if ( pan > 1.0F )
                {
                    pan = 1.0F;
                }
            }
            if ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_DOWN ) )
            {
                vol = vol - 0.1F;
                if ( vol < 0.0F )
                {
                    vol = 0.0F;
                }
            }
            if ( m_keyboard.isKeyDown( java.awt.event.KeyEvent.VK_UP ) )
            {
                vol = vol + 0.1F;
                if ( vol > 1.0F )
                {
                    vol = 1.0F;
                }
            }
            
            m_explosion.setPan( pan );
            m_explosion.setVolume( vol );

            // We draw the text to backbuffer
            try
            {
                m_grfxEngine.clearBackbuffer();
                m_grfxEngine.drawTextAt( strText, middleX, middleY );
                m_grfxEngine.drawTextAt( strText2, middleX2, middleY2 );
                m_grfxEngine.drawTextAt( strText3, middleX3, middleY3 );
                m_grfxEngine.drawTextAt( strText4, middleX4, middleY4 );
                m_grfxEngine.drawTextAt( "Pan:"+ pan, panX, panY );
                m_grfxEngine.drawTextAt( "Vol:"+ vol, volX, volY );
            }
            catch( GameFrameException error )
            {
                System.out.println( "Exception:\n"+error.getMessage() );
                GameFrame.exit(0);
            }

            // We flip the background buffer with the current front buffer thus making the
            // background buffer we just draw into the visible front buffer
            m_grfxEngine.flip();
        }
        
        m_explosion.stop();
    }
}
