/*
GameFrame for Java. Enable platform dependent features without giving up platform independence!
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.engines;

import gameframe.*;
import gameframe.sound.*;

/**
 * A do nothing implementation of the sound object.
 * 
 *@see gameframe.Sample
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */
public class NullSample implements Sample
{
    /** The pan set by user. */
    private float m_pan    = 0.0F;
    /** The volume set by user. */
    private float m_volume = 1.0F;
        
    /**
     * Does nothing.
     * 
     *@since GameFrame for Java 0.9
     */
    public void playOnce()
    {
    }
        
    /**
     * Does nothing.
     * 
     *@since GameFrame for Java 0.9
     */
    public void playLooped()
    {
    }
        
    /**
     * Does nothing.
     * 
     *@since GameFrame for Java 0.9
     */
    public void stop()
    {
    }
        
    /**
     * Returns always false.
     * 
     *@return False.
     *@since GameFrame for Java 0.9
     */
    public boolean isPlaying()
    {
        return false;
    }
        
    /**
     * Sets the volume of the sound. The volume is not used anywhere, it
     * is just stored so that it can be returned upon request.
     * 
     *@param volume The sounds volume.
     *@since GameFrame for Java 0.9
     */
    public void setVolume( float volume )
    {
        m_volume = volume;
    }

    /**
     * Sets the pan of the sound. The pan is not used anywhere, it
     * is just stored so that it can be returned upon request.
     * 
     *@param pan The pan of the sound.
     *@since GameFrame for Java 0.9
     */
    public void setPan( float pan )
    {
        m_pan = pan;
    }

    /**
     * Returns the stored volume.
     * 
     *@return The sounds volume.
     *@since GameFrame for Java 0.9
     */
    public float getVolume()
    {
        return m_volume;
    }
    
    /**
     * Returns the stored pan.
     * 
     *@return The pan of the sound.
     *@since GameFrame for Java 0.9
     */
    public float getPan()
    {
        return m_pan;
    }
    /**
     * Returns a new do nothing implementation of a sound object.
     * 
     *@return Do nothing implementation of a sound object.
     *@since GameFrame for Java 0.9
     */
    public Sample getCopy()
    {
        return new NullSample();
    }

    /**
     * Does nothing.
     * 
     *@since GameFrame for Java 0.9
     */
    public void finalize()
    {
    }
}
