/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.engines.msjava4x;

import gameframe.*;
import gameframe.graphics.*;

import java.awt.*;
import java.awt.image.*;
import java.io.*;
import java.util.*;

import com.ms.com.*;
import com.ms.dll.*;
import com.ms.awt.*;
import com.ms.directX.*;
import com.ms.awt.peer.ComponentPeerX;
import com.ms.wfc.ui.Region;

/**
 * Enumerator for enumerating the modes that a DirectX instance can support.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */
class CModeEnumerator implements IEnumModesCallback
{

    /** A vector of all available video modes that fill the criteria for BPP and refresh rate. */
    private Vector m_aAvailableModes = new Vector(10,10);
    /** The required Bits Per Pixel value of the mode. */
    private int m_modeBpp = CFullscreenGraphicsEngine.DEFAULT_COLOURDEPTH;
    /** The required refresh rate of the mode. */
    private int m_modeRefresh = CFullscreenGraphicsEngine.NO_PREFERRED_REFRESHRATE;

    /**
     * Constructs a mode enumerator that tries to fiend modes with
     * the specified bits per pixel and refresh rate values.
     *@param bpp Bits per pixel value required from the mode.
     *@param refresh The refreshrate value of the mode.
     */
    CModeEnumerator(int bpp, int refresh)
    {
        m_modeBpp = bpp;
        m_modeRefresh = refresh;
    }
    
    /**
     * DirectX callback method for enumerating video modes.
     * @param ddsd Direct draw surface description that describes the enumerated mode.
     * @param arg Application determined argument given to the enumeration method.
     */
    public void callbackEnumModes(DDSurfaceDesc ddsd, IUnknown arg)
    {
        boolean fModeOk = false;
        
        // Check if a specific BPP value is required and if the current mode matches
        if ( m_modeBpp == CFullscreenGraphicsEngine.DEFAULT_COLOURDEPTH )
        {
            // No BPP value is required, but check it is a supported one
            for ( int i = 0; i < GraphicsEngine.ALL_COLOURDEPTHS.length; i++ )
            {
                if ( GraphicsEngine.ALL_COLOURDEPTHS[i] == ddsd.rgbBitCount )
                {
                    fModeOk = true;
                    break;
                }
            }
        }
        else
        {
            // BPP value is, but check it valid
            if ( m_modeBpp == ddsd.rgbBitCount )
            {
                fModeOk = true;
            }
        }
        
        
        // Check if a specific refresh rate value is required and if the current mode matches
        if ((m_modeRefresh != CFullscreenGraphicsEngine.NO_PREFERRED_REFRESHRATE) && (ddsd.refreshRate != m_modeRefresh))
        {
            fModeOk = false;
        }
        
        // If mode is OK add it to list of found modes
        if (fModeOk)
        {
            m_aAvailableModes.addElement(ddsd);
        }
    }
    
    /**
     * Returns the suitable modes that were found by this enumerator.
     *@return Suitable modes that were found.
     */
    public Vector getAvailableModes()
    {
        return m_aAvailableModes;
    }

}
