/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.engines.msjava4x;

import gameframe.*;
import gameframe.util.Timer;
import gameframe.engines.*;

import com.ms.win32.*;

/**
 * Microsoft Java VM specific implementation of the timer. Uses the win32 multimedia
 * timer function (winmm.dll function call timeGetTime()) to calculate the time.
 * Resolution of this timer is 1 ms under Win95/98 and 5 ms under WinNT.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */
class CTimer implements Timer, Finalizable
{
    /** The time from last invocation of calculateTime() method. */
    private int m_lastTime;
    /** The engine factory that created this timer. */
    private EngineFactory m_engineFactory;
    
    /**
     * Constructs a Microsoft Java VM specific timer.
     */
    CTimer( EngineFactory engineFactory )
    {
        m_lastTime = Winmm.timeGetTime();
        m_engineFactory = engineFactory;
    }
    
    /**
     * When invoked calculates the time that has expired since the last invokation in
     * milliseconds.
     *@return The time that has gone since last invokation.
     */
    public float calculateTime()
    {
        int currentTime = Winmm.timeGetTime();
        int elapsedTime = 0;
        
        if (currentTime < m_lastTime)
        {
            if (currentTime < 0)
            {
                // The int value has overflowed
                elapsedTime = (2147483647-m_lastTime)+(currentTime+2147483647+1);
            }
            else
            {
                // The value has crossed the 0 boundary
                elapsedTime = m_lastTime - currentTime;
            }
        }
        else
        {
            elapsedTime = currentTime - m_lastTime;
        }
        
        m_lastTime = currentTime;
        return elapsedTime;
    }
    
    /**
     * Releases all resources used by the timer object.
     */
    public void finalize()
    {
        m_engineFactory.finalizationNotify( this );
    }
}
