/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.engines.msjava4x;

import gameframe.*;

/**
 * Defines an interface for classes that wish to be able to register
 * created bitmaps (in this case the graphics engines). Needed so that
 * either fullscreen graphics engine and windowed graphics engine can
 * both use the same bitmap classes and those classes can notify either
 * engine that a new bitmap was created by them.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */
interface IBitmapStorage
{
    /**
     * Adds a created bitmap to the storage.
     *@param bitmap The bitmap to be added to the storage.
     */
    public void addBitmap(CBitmapBase bitmap);

    /**
     * Removes a bitmap from the storage.
     *@param bitmap The bitmap to be removed from the storage.
     */
    public void removeBitmap(CBitmapBase bitmap);
    
    /**
     * Returns the current data directory.
     *@return The current data directory.
     */
    public String getDataDirectory();
    
}
