/*
GameFrame for Java. Enable platform dependent features without giving up platform independence!
Copyright (C) 2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.graphics;

import gameframe.*;

import java.awt.Color;
import java.util.Vector;

/**
 * Baseclass for all bitmap effect classes that process bitmaps.
 *
 *@author Pasi Kernen 18. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public abstract class BitmapEffect
{
	/**
	 * Processes the given bitmap data in some way. The given bitmap data
     * may or may not be changed (depends on the effect implementation), the
     * resulting bitmap data that is resulted might or might not be the same
     * object that was given as the source data.
	 *@param data The raw bitmap data that is to be processed.
     *@return The resulting bitmap data.
	 */
	public abstract BitmapData processData( BitmapData data );

	/**
     * Resets the effects settings.
     *@since GameFrame for Java 0.9.3
     */
    public abstract void reset();
}
