/*
GameFrame for Java. Enable platform dependent features without giving up platform independence!
Copyright (C) 1999-2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.graphics;

import java.awt.Color;
import java.util.Vector;
import java.util.Enumeration;

/**
 * Groups a number of bitmap effects that are then applied when this effect is used
 * in the order they were added.
 *
 *@author Pasi Kernen 18. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class EffectGroup extends BitmapEffect
{
	/** The currently added effects in this group. */
	protected Vector m_effects = new Vector();
	
	/**
	 * Adds the given effect to this group of effects.
	 *@param effect The effect to be added.
	 */
	public void add( BitmapEffect effect )
	{
		m_effects.addElement( effect );
	}
	
	/**
	 * Removes the given effect from this group of effects.
	 *@param effect The effect to be removed.
	 */
	public void remove( BitmapEffect effect )
	{
		m_effects.removeElement( effect );
	}

    /**
     * Removes all the effects from this group (no effects are applied).
     *@since GameFrame for Java 0.9.3
     */
	public void removeAll()
	{
        m_effects.removeAllElements();
	}
	
    /**
     * Resets all the effects in this group.
     *@since GameFrame for Java 0.9.3
     */
    public void reset()
    {
		for ( Enumeration enum = m_effects.elements(); enum.hasMoreElements(); )
		{
			BitmapEffect effect = (BitmapEffect) enum.nextElement();
			effect.reset();
		}
    }
	
	/**
	 * Processes the given bitmap data with all the effects in this group.
	 *@param data The raw bitmap data that is to be processed.
     *@return The processed data.
	 */
	public BitmapData processData( BitmapData data )
	{
		for ( Enumeration enum = m_effects.elements(); enum.hasMoreElements(); )
		{
			BitmapEffect effect = (BitmapEffect) enum.nextElement();
			data = effect.processData( data );
		}

        return data;
	}
}
