/*
GameFrame for Java. Enable platform dependent features without giving up platform independence!
Copyright (C) 2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.graphics;

/**
 * Defines a flip effect that flips the image
 * (mirrors it around a centered horizontal line).
 *
 *@author Pasi Kernen 18. Jan 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class FlipEffect extends BitmapEffect
{
    /**
     * Does nothing in this effect.
     *@since GameFrame for Java 0.9.3
     */
    public void reset()
    {
    }
	
	/**
	 * Flips (mirrors around a horizontal line) the image.
	 *@param data The raw bitmap data that is to be processed.
     *@return The processed data.
	 */
	public BitmapData processData( BitmapData data )
    {
		int height    = data.getHeight();
		int width     = data.getWidth();
        int pitch     = data.getPitch();
		int[] aPixels = data.getPixels();

		int column;
        int row;
        int sourceOffset;
        int destOffset;
        int[] tempRow = new int[ width ];
        int halfHeight = height / 2;

        for ( row = 0; row < halfHeight; row++ )
        {
            sourceOffset = row * pitch;
            destOffset   = ( height - row - 1 ) * pitch;

            System.arraycopy( aPixels,
                              sourceOffset,
                              tempRow,
                              0,
                              width );
            System.arraycopy( aPixels,
                              destOffset,
                              aPixels,
                              sourceOffset,
                              width );
            System.arraycopy( tempRow,
                              0,
                              aPixels,
                              destOffset,
                              width );

        }

        return data;
    }
}
