/*
GameFrame for Java. Enable platform dependent features without giving up platform independence!
Copyright (C) 2000  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.graphics;

import java.awt.Color;
import java.util.Vector;

/**
 * Mirrors (mirrors around a vertical line) the image.
 *
 *@author Pasi Kernen 18. Mar 2000
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.3
 */
public class MirrorEffect extends BitmapEffect
{
    /**
     * Does nothing in this effect.
     *@since GameFrame for Java 0.9.3
     */
    public void reset()
    {
    }

	/**
     * Mirrors (mirrors around a vertical line) the image.
	 *@param data The raw bitmap data that is to be processed.
     *@return The processed data.
	 */
	public BitmapData processData( BitmapData data )
    {
		int height    = data.getHeight();
		int width     = data.getWidth();
        int pitch     = data.getPitch();
		int[] aPixels = data.getPixels();

		int temp;
        int halfWidth = width/2;
        int mirrorColumn;
        int rowOffset;

        for ( int row = 0; row < height; row++ )
        {
            rowOffset = row * pitch;
            for ( int column = 0; column < halfWidth; column++ )
            {
                mirrorColumn = width - column - 1;
                temp = aPixels[column + rowOffset];
                aPixels[column + rowOffset] = aPixels[mirrorColumn + rowOffset];
                aPixels[mirrorColumn + rowOffset] = temp;
            }
        }

        return data;
    }
}
