/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.input;

import gameframe.*;

import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;

/**
 * This interface is meant for input devices that are pointer or mouse like in their
 * operation. This means that the device has a cursor visible on the screen (is
 * be implemented by the engine implementation if not provided by the OS) and
 * has from one to many buttons.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */
public interface PointerDevice
{
    /**
     * Returns the X-coordinate of the pointer devices current location. If the mouse
     * is outside of the screen returns -1.
     * 
     *@return Pointers current X-location or -1 if not on screen.
     *@since GameFrame for Java 0.9
     */
    public int getX();
    
    /**
     * Returns the Y-coordinate of the pointer devices current location. If the mouse
     * is outside of the screen returns -1.
     * 
     *@return Pointers current Y-location or -1 if not on screen.
     *@since GameFrame for Java 0.9
     */
    public int getY();

    /**
     * Returns true if the button is currently down. Id numbers should be
     * 0 = primary button, 1 = secondary or "popup menu" button, 2 etc. for rest of
     * the buttons. Max. 3 buttons are supported (button id's from 0 to 2).
     * 
     *@param buttonId The number of the button we want to query.
     *@return True if the button is or was down.
     *@since GameFrame for Java 0.9
     */
    public boolean isButtonDown( int buttonId );

    /**
     * Returns true if the button was briefly kept down after last reading
     * of the buttons state (after last call made to wasButtonDown or
     * getButtonDownCount methods with the same button id number). Id numbers should be
     * 0 = primary button, 1 = secondary or "popup menu" button, 2 etc. for rest of
     * the buttons. Max. 3 buttons are supported (button id's from 0 to 2).
     * 
     *@param buttonId The number of the button we want to query.
     *@return True if the button is or was down.
     *@since GameFrame for Java 0.9
     */
    public boolean wasButtonDown( int buttonId );
    
    /**
     * Returns the number of times the button has been stroken since last reading
     * (after last call made to wasButtonDown or getButtonDownCount methods with the
     * same button id number). Id numbers should be
     * 0 = primary button, 1 = secondary or "popup menu" button, 2 = third button.
     * Max. 3 buttons are supported (button id's from 0 to 2).
     * 
     *@param buttonId The number of the button we want to query.
     *@return The number of times the button was stroken (pressed and released)
     *@since GameFrame for Java 0.9
     */
    public int getButtonDownCount( int buttonId );
}
