/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.sound;

/**
 * Defines the interface for a representation of a sample. Offers methods for
 * panning, attennuating and controlling the playback of the sample.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 */    
public interface Sample extends Sound
{
    /**
     * <p>Sets the volume of the sound. Value of 0.0 means that the sound should be
     * inaudible and value of 1.0 means the sound is played at its normal volume.
     * Values above 1.0 are treated as 1.0 and values below 0.0 are treated as 0.0.</p>
     *
     * <p>NOTE: This feature is optional as it can't be supported on all platform implementations,
     * but all implementations offer at least a "do nothing" method.</p>
     *
     *@param volume The sounds volume.
     *@since GameFrame for Java 0.9
     */
    public void setVolume( float volume );
    
    /**
     * <p>Sets the pan of the sound. Value of -1.0 means that the sound will be
     * heard only from the left speaker and value of 1.0 means that the sound
     * will be heard only from the right speaker. Value of 0.0 means that
     * the sound is heard with equal volume from both speakers.
     * Values above 1.0 are treated as 1.0 and values below -1.0 are treated as -1.0.</p>
     * 
     * <p>NOTE: This feature is optional as it can't be supported on all platform implementations,
     * but all implementations offer at least a "do nothing" method.</p>
     * 
     *@param pan The pan of the sound.
     *@since GameFrame for Java 0.9
     */
    public void setPan( float pan );

    /**
     * Returns the volume of the sound. Value of 0.0 means that the sound should be
     * inaudible and value of 1.0 means the sound is played at its normal volume.
     * 
     *@return The sounds volume.
     *@since GameFrame for Java 0.9
     */
    public float getVolume();
    
    /**
     * <p>Returns the pan of the sound. Value of -1.0 means that the sound will be
     * heard only from the left speaker and value of 1.0 means that the sound
     * will be heard only from the right speaker. Value of 0.0 means that
     * the sound is heard with equal volume from both speakers.</p>
     * 
     * <p>NOTE: This feature is optional as it can't be supported on all platform implementations,
     * but all implementations offer at least a "do nothing" method.</p>
     * 
     *@return The pan of the sound.
     *@since GameFrame for Java 0.9
     */
    public float getPan();
    
    /**
     * Returns a copy of this sound object that is independent from the
     * original sound object. This new sound object can be started/stopped
     * independently from the original sound object, but it most likely
     * uses the same sample data. Using this method to get multiple instances
     * of one sound will save memory on some implementations and is thus the
     * preferred way to duplicate sound objects.
     *
     *@return A independent copy of this sound or null if copy fails.
     *@since GameFrame for Java 0.9
     */
    public Sample getCopy();
}
