/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.sound;

/**
 * Defines the base interface for all representations of a sound.
 * Offers methods for controlling the playback of a sound.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9.2
 */    
public interface Sound
{
    /**
     * Plays the sound once and then stops. If the sound is
     * already playing then it is stopped and restarted.
     * 
     *@since GameFrame for Java 0.9.2
     */
    public void playOnce();
        
    /**
     * Plays the sound over and over again (looping).
     * If the sound is already playing then it is stopped and
     * restarted.
     * 
     *@since GameFrame for Java 0.9.2
     */
    public void playLooped();
        
    /**
     * Stops playing the sound.
     * 
     *@since GameFrame for Java 0.9.2
     */
    public void stop();
   
    /**
     * Returns true if play() or playLooped() has been invoked on the sound and
     * the stop() hasn't been called after that. This method doesn't reflect the fact
     * if the sound can be heard or not at the moment.
     * 
     *@since GameFrame for Java 0.9.2
     */
    public boolean isPlaying();

    /**
     * Frees all the resources that are used by the sound representation.
     * This method is quite slow to execute and should preferrably be called upon
     * exiting the game or between level changes etc.
     * 
     *@since GameFrame for Java 0.9.2
     */
    public void finalize();
}
