/*
GameFrame for Java. Makes your games run better in some Java platforms.
Copyright (C) 1999  Pasi Kernen

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

The author can be contacted at eMail address: javanerd@geocities.com
*/
package gameframe.util;

/**
 * Interface for a generic timer class that times the (average or exact, depending
 * on implementation) time between the calls made to the calculateTime() method.
 * Useful for e.g. finding out how long a main game loop takes and adjusting the game
 * timing accordingly. The maximum time that a timer class must be able to calculate
 * is 10000 milliseconds = 10 seconds, this should suffice for all purposes where
 * exact timing is required. In other cases, use the java.lang.System.currentTimeMillis()
 * method directly in your application.
 *
 *@author Pasi Kernen 16. May 1999
 *@version GameFrame for Java 0.9.4
 *@since GameFrame for Java 0.9
 *@see gameframe.GameFrame
 */
public interface Timer
{
    /**
     * When invoked calculates and returns the time that has elapsed since the last
     * invokation in milliseconds (actual resolutin may vary from implementation to
     * implementation).
     * 
     *@return The time that has elapsed since last invokation.
     *@since GameFrame for Java 0.9
     */
    public float calculateTime();


    /**
     * Frees all the resources that are used by the timer.
     *@since GameFrame for Java 0.9.2
     */
    public void finalize();
}
